@@ -21,6 +21,7 @@ from .models.cbamresnet import *
 from .models.resattnet import *
 from .models.sknet import *
 from .models.scnet import *
+from .models.regnet import *
 from .models.diaresnet import *
 from .models.diapreresnet import *
 from .models.pyramidnet import *
@@ -45,6 +46,7 @@ from .models.dla import *
 from .models.msdnet import *
 from .models.fishnet import *
 from .models.espnetv2 import *
+from .models.dicenet import *
 from .models.hrnet import *
 from .models.vovnet import *
 from .models.selecsls import *
@@ -70,6 +72,7 @@ from .models.fbnet import *
 from .models.xception import *
 from .models.inceptionv3 import *
 from .models.inceptionv4 import *
+from .models.inceptionresnetv1 import *
 from .models.inceptionresnetv2 import *
 from .models.polynet import *
 from .models.nasnet import *
@@ -117,9 +120,14 @@ from .models.fcn8sd import *
 from .models.pspnet import *
 from .models.deeplabv3 import *
 from .models.icnet import *
+from .models.fastscnn import *
+from .models.cgnet import *
+from .models.dabnet import *
 from .models.sinet import *
 from .models.bisenet import *
 from .models.danet import *
+from .models.fpenet import *
+from .models.lednet import *
 
 from .models.superpointnet import *
 
@@ -136,6 +144,10 @@ from .models.visemenet import *
 from .models.voca import *
 from .models.nvpattexp import *
 
+from .models.jasper import *
+from .models.jasperdr import *
+from .models.quartznet import *
+
 # from .models.others.oth_simple_pose_resnet import *
 # from .models.others.oth_mobile_pose import *
 # from .models.others.oth_alpha_pose import *
@@ -143,8 +155,9 @@ from .models.nvpattexp import *
 # from .models.others.oth_centernet import *
 # from .models.others.oth_resnest import *
 # from .models.others.oth_danet import *
+# from .models.others.oth_fastscnn import *
 
-from .models.regnet import *
+from .models.regnetv import *
 
 __all__ = ['get_model']
 
@@ -277,6 +290,7 @@ _models = {
     'resnestabc14': resnestabc14,
     'resnesta18': resnesta18,
     'resnestabc26': resnestabc26,
+    'resnestabc38': resnestabc38,
     'resnesta50': resnesta50,
     'resnesta101': resnesta101,
     'resnesta152': resnesta152,
@@ -337,6 +351,35 @@ _models = {
     'scneta50': scneta50,
     'scneta101': scneta101,
 
+    'regnetx002': regnetx002,
+    'regnetx004': regnetx004,
+    'regnetx006': regnetx006,
+    'regnetx008': regnetx008,
+    'regnetx016': regnetx016,
+    'regnetx032': regnetx032,
+    'regnetx040': regnetx040,
+    'regnetx064': regnetx064,
+    'regnetx080': regnetx080,
+    'regnetx120': regnetx120,
+    'regnetx160': regnetx160,
+    'regnetx320': regnetx320,
+
+    'regnety002': regnety002,
+    'regnety004': regnety004,
+    'regnety006': regnety006,
+    'regnety008': regnety008,
+    'regnety016': regnety016,
+    'regnety032': regnety032,
+    'regnety040': regnety040,
+    'regnety064': regnety064,
+    'regnety080': regnety080,
+    'regnety120': regnety120,
+    'regnety160': regnety160,
+    'regnety320': regnety320,
+
+    'regnetz002': regnetz002,
+    'regnetw002': regnetw002,
+
     'diaresnet10': diaresnet10,
     'diaresnet12': diaresnet12,
     'diaresnet14': diaresnet14,
@@ -463,6 +506,15 @@ _models = {
     'espnetv2_w3d2': espnetv2_w3d2,
     'espnetv2_w2': espnetv2_w2,
 
+    'dicenet_wd5': dicenet_wd5,
+    'dicenet_wd2': dicenet_wd2,
+    'dicenet_w3d4': dicenet_w3d4,
+    'dicenet_w1': dicenet_w1,
+    'dicenet_w5d4': dicenet_w5d4,
+    'dicenet_w3d2': dicenet_w3d2,
+    'dicenet_w7d8': dicenet_w7d8,
+    'dicenet_w2': dicenet_w2,
+
     'hrnet_w18_small_v1': hrnet_w18_small_v1,
     'hrnet_w18_small_v2': hrnet_w18_small_v2,
     'hrnetv2_w18': hrnetv2_w18,
@@ -594,7 +646,9 @@ _models = {
 
     'xception': xception,
     'inceptionv3': inceptionv3,
+    'inceptionv3_gl': inceptionv3_gl,
     'inceptionv4': inceptionv4,
+    'inceptionresnetv1': inceptionresnetv1,
     'inceptionresnetv2': inceptionresnetv2,
     'polynet': polynet,
 
@@ -1080,6 +1134,11 @@ _models = {
 
     'icnet_resnetd50b_cityscapes': icnet_resnetd50b_cityscapes,
 
+    'fastscnn_cityscapes': fastscnn_cityscapes,
+
+    'cgnet_cityscapes': cgnet_cityscapes,
+    'dabnet_cityscapes': dabnet_cityscapes,
+
     'sinet_cityscapes': sinet_cityscapes,
 
     'bisenet_resnet18_celebamaskhq': bisenet_resnet18_celebamaskhq,
@@ -1087,6 +1146,10 @@ _models = {
     'danet_resnetd50b_cityscapes': danet_resnetd50b_cityscapes,
     'danet_resnetd101b_cityscapes': danet_resnetd101b_cityscapes,
 
+    'fpenet_cityscapes': fpenet_cityscapes,
+
+    'lednet_cityscapes': lednet_cityscapes,
+
     'superpointnet': superpointnet,
 
     'alphapose_fastseresnet101b_coco': alphapose_fastseresnet101b_coco,
@@ -1125,6 +1188,25 @@ _models = {
     'voca8flame': voca8flame,
     'nvpattexp116bazel76': nvpattexp116bazel76,
 
+    'jasper5x3': jasper5x3,
+    'jasper10x4': jasper10x4,
+    'jasper10x5': jasper10x5,
+
+    'jasperdr10x5_en': jasperdr10x5_en,
+    'jasperdr10x5_en_nr': jasperdr10x5_en_nr,
+
+    'quartznet5x5_en_ls': quartznet5x5_en_ls,
+    'quartznet15x5_en': quartznet15x5_en,
+    'quartznet15x5_en_nr': quartznet15x5_en_nr,
+    'quartznet15x5_fr': quartznet15x5_fr,
+    'quartznet15x5_de': quartznet15x5_de,
+    'quartznet15x5_it': quartznet15x5_it,
+    'quartznet15x5_es': quartznet15x5_es,
+    'quartznet15x5_ca': quartznet15x5_ca,
+    'quartznet15x5_pl': quartznet15x5_pl,
+    'quartznet15x5_ru': quartznet15x5_ru,
+    'quartznet15x5_ru34': quartznet15x5_ru34,
+
     # 'oth_simple_pose_resnet18_v1b': oth_simple_pose_resnet18_v1b,
     # 'oth_simple_pose_resnet50_v1b': oth_simple_pose_resnet50_v1b,
     # 'oth_simple_pose_resnet101_v1b': oth_simple_pose_resnet101_v1b,
@@ -1170,31 +1252,18 @@ _models = {
     # 'oth_danet_resnet50_citys': oth_danet_resnet50_citys,
     # 'oth_danet_resnet101_citys': oth_danet_resnet101_citys,
 
-    'regnetx002': regnetx002,
-    'regnetx004': regnetx004,
-    'regnetx006': regnetx006,
-    'regnetx008': regnetx008,
-    'regnetx016': regnetx016,
-    'regnetx032': regnetx032,
-    'regnetx040': regnetx040,
-    'regnetx064': regnetx064,
-    'regnetx080': regnetx080,
-    'regnetx120': regnetx120,
-    'regnetx160': regnetx160,
-    'regnetx320': regnetx320,
-
-    'regnety002': regnety002,
-    'regnety004': regnety004,
-    'regnety006': regnety006,
-    'regnety008': regnety008,
-    'regnety016': regnety016,
-    'regnety032': regnety032,
-    'regnety040': regnety040,
-    'regnety064': regnety064,
-    'regnety080': regnety080,
-    'regnety120': regnety120,
-    'regnety160': regnety160,
-    'regnety320': regnety320,
+    'regnetv002': regnetv002,
+    'regnetv004': regnetv004,
+    'regnetv006': regnetv006,
+    'regnetv008': regnetv008,
+    'regnetv016': regnetv016,
+    'regnetv032': regnetv032,
+    'regnetv040': regnetv040,
+    'regnetv064': regnetv064,
+    'regnetv080': regnetv080,
+    'regnetv120': regnetv120,
+    'regnetv160': regnetv160,
+    'regnetv320': regnetv320,
 }
 
 
@@ -1207,7 +1276,7 @@ def get_model(name, **kwargs):
     name : str
         Name of model.
 
-    Returns
+    Returns:
     -------
     HybridBlock
         Resulted model.
