@@ -135,7 +135,7 @@ class CenterNetHeatmapMaxDet(HybridBlock):
     """
     CenterNet decoder for heads (heatmap, wh, reg).
 
-    Parameters
+    Parameters:
     ----------
     topk : int, default 40
         Keep only `topk` detections.
@@ -207,7 +207,7 @@ class CenterNet(HybridBlock):
     """
     CenterNet model from 'Objects as Points,' https://arxiv.org/abs/1904.07850.
 
-    Parameters
+    Parameters:
     ----------
     backbone : nn.Sequential
         Feature extractor.
@@ -294,7 +294,7 @@ def get_centernet(backbone,
     """
     Create CenterNet model with specific parameters.
 
-    Parameters
+    Parameters:
     ----------
     backbone : nn.Sequential
         Feature extractor.
@@ -311,7 +311,7 @@ def get_centernet(backbone,
     root : str, default '~/.mxnet/models'
         Location for keeping the model parameters.
 
-    Returns
+    Returns:
     -------
     HybridBlock
         A network.
