@@ -2,14 +2,15 @@
     Common routines for models in Gluon.
 """
 
-__all__ = ['round_channels', 'get_activation_layer', 'ReLU6', 'PReLU2', 'HSigmoid', 'HSwish', 'Softmax',
+__all__ = ['round_channels', 'BreakBlock', 'get_activation_layer', 'ReLU6', 'PReLU2', 'HSigmoid', 'HSwish', 'Softmax',
            'SelectableDense', 'BatchNormExtra', 'DenseBlock', 'ConvBlock1d', 'conv1x1', 'conv3x3', 'depthwise_conv3x3',
-           'ConvBlock', 'conv1x1_block', 'conv3x3_block', 'conv7x7_block', 'dwconv_block', 'dwconv3x3_block',
-           'dwconv5x5_block', 'dwsconv3x3_block', 'PreConvBlock', 'pre_conv1x1_block', 'pre_conv3x3_block',
-           'DeconvBlock', 'InterpolationBlock', 'ChannelShuffle', 'ChannelShuffle2', 'SEBlock', 'SABlock',
-           'SAConvBlock', 'saconv3x3_block', 'DucBlock', 'split', 'IBN', 'DualPathSequential', 'ParametricSequential',
-           'Concurrent', 'SequentialConcurrent', 'ParametricConcurrent', 'Hourglass', 'SesquialteralHourglass',
-           'MultiOutputSequential', 'ParallelConcurent', 'HeatmapMaxDetBlock']
+           'ConvBlock', 'conv1x1_block', 'conv3x3_block', 'conv5x5_block', 'conv7x7_block', 'dwconv_block',
+           'dwconv3x3_block', 'dwconv5x5_block', 'dwsconv3x3_block', 'PreConvBlock', 'pre_conv1x1_block',
+           'pre_conv3x3_block', 'DeconvBlock', 'NormActivation', 'InterpolationBlock', 'ChannelShuffle',
+           'ChannelShuffle2', 'SEBlock', 'SABlock', 'SAConvBlock', 'saconv3x3_block', 'DucBlock', 'split', 'IBN',
+           'DualPathSequential', 'ParametricSequential', 'Concurrent', 'SequentialConcurrent', 'ParametricConcurrent',
+           'Hourglass', 'SesquialteralHourglass', 'MultiOutputSequential', 'ParallelConcurent',
+           'DualPathParallelConcurent', 'HeatmapMaxDetBlock']
 
 import math
 from inspect import isfunction
@@ -29,7 +30,7 @@ def round_channels(channels,
     divisor : int, default 8
         Alignment value.
 
-    Returns
+    Returns:
     -------
     int
         Weighted number of channels.
@@ -40,6 +41,20 @@ def round_channels(channels,
     return rounded_channels
 
 
+class BreakBlock(HybridBlock):
+    """
+    Break coonnection block for hourglass.
+    """
+    def __init__(self, prefix=None, params=None):
+        super(BreakBlock, self).__init__(prefix=prefix, params=params)
+
+    def hybrid_forward(self, F, x):
+        return None
+
+    def __repr__(self):
+        return '{name}()'.format(name=self.__class__.__name__)
+
+
 class ReLU6(HybridBlock):
     """
     ReLU6 activation layer.
@@ -141,7 +156,7 @@ def get_activation_layer(activation):
     activation : function, or str, or HybridBlock
         Activation function or name of activation function.
 
-    Returns
+    Returns:
     -------
     HybridBlock
         Activation layer.
@@ -459,7 +474,10 @@ def conv3x3(in_channels,
 
 
 def depthwise_conv3x3(channels,
-                      strides):
+                      strides=1,
+                      padding=1,
+                      dilation=1,
+                      use_bias=False):
     """
     Depthwise convolution 3x3 layer.
 
@@ -467,16 +485,23 @@ def depthwise_conv3x3(channels,
     ----------
     channels : int
         Number of input/output channels.
-    strides : int or tuple/list of 2 int
+    strides : int or tuple/list of 2 int, default 1
         Strides of the convolution.
+    padding : int or tuple/list of 2 int, default 1
+        Padding value for convolution layer.
+    dilation : int or tuple/list of 2 int, default 1
+        Dilation value for convolution layer.
+    use_bias : bool, default False
+        Whether the layer uses a bias vector.
     """
     return nn.Conv2D(
         channels=channels,
         kernel_size=3,
         strides=strides,
-        padding=1,
+        padding=padding,
+        dilation=dilation,
         groups=channels,
-        use_bias=False,
+        use_bias=use_bias,
         in_channels=channels)
 
 
@@ -563,6 +588,7 @@ class ConvBlock(HybridBlock):
 def conv1x1_block(in_channels,
                   out_channels,
                   strides=1,
+                  padding=0,
                   groups=1,
                   use_bias=False,
                   use_bn=True,
@@ -582,6 +608,8 @@ def conv1x1_block(in_channels,
         Number of output channels.
     strides : int or tuple/list of 2 int, default 1
         Strides of the convolution.
+    padding : int or tuple/list of 2 int, default 0
+        Padding value for convolution layer.
     groups : int, default 1
         Number of groups.
     use_bias : bool, default False
@@ -602,7 +630,7 @@ def conv1x1_block(in_channels,
         out_channels=out_channels,
         kernel_size=1,
         strides=strides,
-        padding=0,
+        padding=padding,
         groups=groups,
         use_bias=use_bias,
         use_bn=use_bn,
@@ -1341,6 +1369,45 @@ class DeconvBlock(HybridBlock):
         return x
 
 
+class NormActivation(HybridBlock):
+    """
+    Activation block with preliminary batch normalization. It's used by itself as the final block in PreResNet.
+
+    Parameters:
+    ----------
+    in_channels : int
+        Number of input channels.
+    bn_epsilon : float, default 1e-5
+        Small float added to variance in Batch norm.
+    bn_use_global_stats : bool, default False
+        Whether global moving statistics is used instead of local batch-norm for BatchNorm layers.
+    bn_cudnn_off : bool, default False
+        Whether to disable CUDNN batch normalization operator.
+    activation : function or str or None, default nn.Activation('relu')
+        Activation function or name of activation function.
+    """
+    def __init__(self,
+                 in_channels,
+                 bn_epsilon=1e-5,
+                 bn_use_global_stats=False,
+                 bn_cudnn_off=False,
+                 activation=(lambda: nn.Activation("relu")),
+                 **kwargs):
+        super(NormActivation, self).__init__(**kwargs)
+        with self.name_scope():
+            self.bn = BatchNormExtra(
+                in_channels=in_channels,
+                epsilon=bn_epsilon,
+                use_global_stats=bn_use_global_stats,
+                cudnn_off=bn_cudnn_off)
+            self.activ = get_activation_layer(activation)
+
+    def hybrid_forward(self, F, x):
+        x = self.bn(x)
+        x = self.activ(x)
+        return x
+
+
 class InterpolationBlock(HybridBlock):
     """
     Interpolation block.
@@ -1415,7 +1482,7 @@ def channel_shuffle(x,
     groups : int
         Number of groups.
 
-    Returns
+    Returns:
     -------
     Symbol or NDArray
         Resulted tensor.
@@ -1445,6 +1512,12 @@ class ChannelShuffle(HybridBlock):
     def hybrid_forward(self, F, x):
         return channel_shuffle(x, self.groups)
 
+    def __repr__(self):
+        s = "{name}(groups={groups})"
+        return s.format(
+            name=self.__class__.__name__,
+            groups=self.groups)
+
 
 def channel_shuffle2(x,
                      channels_per_group):
@@ -1459,7 +1532,7 @@ def channel_shuffle2(x,
     channels_per_group : int
         Number of channels per group.
 
-    Returns
+    Returns:
     -------
     Symbol or NDArray
         Resulted tensor.
@@ -1884,7 +1957,7 @@ def split(x,
     axis : int, default 1
         Axis along which to split.
 
-    Returns
+    Returns:
     -------
     Tuple of Symbol or NDArray
         Resulted tensor.
@@ -2024,17 +2097,25 @@ class Concurrent(nn.HybridSequential):
         The axis on which to concatenate the outputs.
     stack : bool, default False
         Whether to concatenate tensors along a new dimension.
+    merge_type : str, default None
+        Type of branch merging.
     branches : list of HybridBlock, default None
         Whether to concatenate tensors along a new dimension.
     """
     def __init__(self,
                  axis=1,
                  stack=False,
+                 merge_type=None,
                  branches=None,
                  **kwargs):
         super(Concurrent, self).__init__(**kwargs)
+        assert (merge_type is None) or (merge_type in ["cat", "stack", "sum"])
         self.axis = axis
         self.stack = stack
+        if merge_type is not None:
+            self.merge_type = merge_type
+        else:
+            self.merge_type = "stack" if stack else "cat"
         if branches is not None:
             with self.name_scope():
                 for branch in branches:
@@ -2044,10 +2125,14 @@ class Concurrent(nn.HybridSequential):
         out = []
         for block in self._children.values():
             out.append(block(x))
-        if self.stack:
+        if self.merge_type == "stack":
             out = F.stack(*out, axis=self.axis)
-        else:
+        elif self.merge_type == "cat":
             out = F.concat(*out, dim=self.axis)
+        elif self.merge_type == "sum":
+            out = F.stack(*out, axis=self.axis).sum(axis=self.axis)
+        else:
+            raise NotImplementedError()
         return out
 
 
@@ -2301,18 +2386,84 @@ class ParallelConcurent(nn.HybridSequential):
     """
     A sequential container with multiple inputs and multiple outputs.
     Modules will be executed in the order they are added.
+
+    Parameters:
+    ----------
+    axis : int, default 1
+        The axis on which to concatenate the outputs.
+    merge_type : str, default 'list'
+        Type of branch merging.
     """
     def __init__(self,
+                 axis=1,
+                 merge_type="list",
                  **kwargs):
         super(ParallelConcurent, self).__init__(**kwargs)
+        assert (merge_type is None) or (merge_type in ["list", "cat", "stack", "sum"])
+        self.axis = axis
+        self.merge_type = merge_type
 
     def hybrid_forward(self, F, x):
         out = []
         for block, xi in zip(self._children.values(), x):
             out.append(block(xi))
+        if self.merge_type == "list":
+            pass
+        elif self.merge_type == "stack":
+            out = F.stack(*out, axis=self.axis)
+        elif self.merge_type == "cat":
+            out = F.concat(*out, dim=self.axis)
+        elif self.merge_type == "sum":
+            out = F.stack(*out, axis=self.axis).sum(axis=self.axis)
+        else:
+            raise NotImplementedError()
         return out
 
 
+class DualPathParallelConcurent(nn.HybridSequential):
+    """
+    A sequential container with multiple dual-path inputs and single/multiple outputs.
+    Blocks will be executed in the order they are added.
+
+    Parameters:
+    ----------
+    axis : int, default 1
+        The axis on which to concatenate the outputs.
+    merge_type : str, default 'list'
+        Type of branch merging.
+    """
+    def __init__(self,
+                 axis=1,
+                 merge_type="list",
+                 **kwargs):
+        super(DualPathParallelConcurent, self).__init__(**kwargs)
+        assert (merge_type is None) or (merge_type in ["list", "cat", "stack", "sum"])
+        self.axis = axis
+        self.merge_type = merge_type
+
+    def hybrid_forward(self, F, x1, x2):
+        x1_out = []
+        x2_out = []
+        for block, x1i, x2i in zip(self._children.values(), x1, x2):
+            y1i, y2i = block(x1i, x2i)
+            x1_out.append(y1i)
+            x2_out.append(y2i)
+        if self.merge_type == "list":
+            pass
+        elif self.merge_type == "stack":
+            x1_out = F.stack(*x1_out, axis=self.axis)
+            x2_out = F.stack(*x2_out, axis=self.axis)
+        elif self.merge_type == "cat":
+            x1_out = F.concat(*x1_out, dim=self.axis)
+            x2_out = F.concat(*x2_out, dim=self.axis)
+        elif self.merge_type == "sum":
+            x1_out = F.stack(*x1_out, axis=self.axis).sum(axis=self.axis)
+            x2_out = F.stack(*x2_out, axis=self.axis).sum(axis=self.axis)
+        else:
+            raise NotImplementedError()
+        return x1_out, x2_out
+
+
 class HeatmapMaxDetBlock(HybridBlock):
     """
     Heatmap maximum detector block (for human pose estimation task).
