@@ -10,8 +10,8 @@ import logging
 from mxnet.gluon.utils import download, check_sha1
 
 _model_sha1 = {name: (error, checksum, repo_release_tag) for name, error, checksum, repo_release_tag in [
-    ('alexnet', '1770', '3883d21e1283110be71430de966e7223fa5afcb3', 'v0.0.394'),
-    ('alexnetb', '1853', '9762fd33943ba48ed40329f145ff5195b9769535', 'v0.0.384'),
+    ('alexnet', '1610', '4dd7cfb6275229c3b3889ec7ad29f8d48a499193', 'v0.0.481'),
+    ('alexnetb', '1705', '0181007ac2ba5d5c051346af1eea4a00c36f34e9', 'v0.0.485'),
     ('zfnet', '1678', '3299fdce9712697f9e03e1a0cf741745553a28cf', 'v0.0.395'),
     ('zfnetb', '1459', '7a654810eced689323e414030165cf1392c9684f', 'v0.0.400'),
     ('vgg11', '1016', '3d78e0ec95d358577acf8b2e2f768a72ec319ee3', 'v0.0.381'),
@@ -23,29 +23,29 @@ _model_sha1 = {name: (error, checksum, repo_release_tag) for name, error, checks
     ('bn_vgg16', '0757', '90441925c7c19c9db6bf96824c2440774c0e54df', 'v0.0.359'),
     ('bn_vgg19', '0689', 'cd8f4229e5e757ba951afc6eb1a4ec7a471022f7', 'v0.0.360'),
     ('bn_vgg11b', '0975', '685ae89dcf3916b9c6e887d4c5bc441a34253744', 'v0.0.407'),
-    ('bn_vgg13b', '1016', 'f384ff5263d4c79c22b8fc1a2bdc19c31e1b12b9', 'v0.0.110'),
-    ('bn_vgg16b', '0865', 'b5e33db8aaa77e0a1336e5eb218345a2586f5469', 'v0.0.110'),
-    ('bn_vgg19b', '0815', '3a0e43e66836ea5ab4f6d4c0425e2ab2abcb5766', 'v0.0.110'),
+    ('bn_vgg13b', '0912', 'fc678318391d45465bda4aa17744dc0d148135e3', 'v0.0.488'),
+    ('bn_vgg16b', '0775', '77dad99b4f72176870655ffbf59e96f3b9570a0b', 'v0.0.489'),
+    ('bn_vgg19b', '0735', '8d9a132bfd9230304e588ec159170ee3173d64ba', 'v0.0.490'),
     ('bninception', '0754', '75225419bae387931f6c8ccc19dc48fb1cc8cdae', 'v0.0.405'),
-    ('resnet10', '1385', 'a996427482bd5bd427db1d811d2a69bfd35987fc', 'v0.0.248'),
-    ('resnet12', '1303', '8f492c28cd7c4c1bfc89c88649629e64487d5d00', 'v0.0.253'),
-    ('resnet14', '1220', 'fcdddcef6a9fe9c472058e883a08cf09bbeb6738', 'v0.0.256'),
-    ('resnetbc14b', '1116', 'c4ffed61c1b542e33794f22ab48bce568b9bf7bb', 'v0.0.309'),
-    ('resnet16', '1088', '2bc07547e9d007825c89bdcf6879e346e7372028', 'v0.0.259'),
+    ('resnet10', '1253', '651853ca974959c978f39b965b928d7c616796d3', 'v0.0.483'),
+    ('resnet12', '1203', 'a41948541130b9ebf8285412b38c668198e4ad4f', 'v0.0.485'),
+    ('resnet14', '1086', '5d9f22a7aa6c821eb69fc043af2da040f36110eb', 'v0.0.491'),
+    ('resnetbc14b', '1033', '4ff348bebc7696cd219be605668bb76546dd9641', 'v0.0.481'),
+    ('resnet16', '0978', '2c28373c9ce1f50ff6a4b47a16a3d1bc2e557c75', 'v0.0.493'),
     ('resnet18_wd4', '1740', 'a74ea15d056a84133e02706a6c7f8ed8f50c8462', 'v0.0.262'),
     ('resnet18_wd2', '1284', '9a5154065311c8ffbbc57b20a443b205c7a910fa', 'v0.0.263'),
     ('resnet18_w3d4', '1066', '1a574a4198a5bbf01572c2b3f091eb824ff8196e', 'v0.0.266'),
-    ('resnet18', '0921', '3f8091d8b0af7b82784e5300ba9fefe0c43342ec', 'v0.0.469'),
-    ('resnet26', '0837', 'd81d836f0e8808d7bc3d85db08207b91d4b2c68f', 'v0.0.305'),
+    ('resnet18', '0867', '711ed8ab624c4c580e90321989aef6174ad2991d', 'v0.0.478'),
+    ('resnet26', '0823', 'a2746eb21d73c3c85edacabe36d680988986f890', 'v0.0.489'),
     ('resnetbc26b', '0758', '2b5e8d0888936a340ea13c7e8ba30b237cd62f1c', 'v0.0.313'),
     ('resnet34', '0743', '5cdeeccda6f87fe13aed279213006061a8b42037', 'v0.0.291'),
     ('resnetbc38b', '0672', '820944641ba54f4aaa43d2a305ab52b9dcb740c7', 'v0.0.328'),
     ('resnet50', '0604', 'a71d1d2a8e8e4259742bbd67c386623233b57c6c', 'v0.0.329'),
     ('resnet50b', '0611', 'ca12f8d804000bf5202e2e3838dec7ef6b772149', 'v0.0.308'),
-    ('resnet101', '0599', 'a6d3a5f4933794d56b61867c050ee730f6310f1b', 'v0.0.1'),
+    ('resnet101', '0516', '75a3105c609aedb89d63dd3dc47b578f41fff6be', 'v0.0.499'),
     ('resnet101b', '0512', 'af5c4233b28c8b7acd3b3ebe02f9f2eda2c77824', 'v0.0.357'),
-    ('resnet152', '0535', 'bbdd7ed1f33a9b33c75635d78143e8bd00e204e0', 'v0.0.144'),
-    ('resnet152b', '0480', '7277968cbbc5e55e681b6f13784c93c4e4ec3d6d', 'v0.0.378'),
+    ('resnet152', '0444', '15f2dd80f964225e685e7564cecd04911feb97ee', 'v0.0.518'),
+    ('resnet152b', '0429', '45a3ad0f989852a4456c907fa3b40b00dd24937c', 'v0.0.517'),
     ('preresnet10', '1401', '2b96c0818dbabc422e98d8fbfc9b684c023922ed', 'v0.0.249'),
     ('preresnet12', '1321', 'b628efb5415784075e18b6734b1ba1e5c7280dee', 'v0.0.257'),
     ('preresnet14', '1218', 'd65fa6287414d9412e34ac0df6921eaa5646a2b6', 'v0.0.260'),
@@ -61,87 +61,94 @@ _model_sha1 = {name: (error, checksum, repo_release_tag) for name, error, checks
     ('preresnetbc38b', '0633', '809d2defea82276fdd7ff2faafc1f6ffe57c93b5', 'v0.0.348'),
     ('preresnet50', '0620', '50f13b2d3fd197c8aa721745adaf2d6615fd8c16', 'v0.0.330'),
     ('preresnet50b', '0632', '951de2dc558f94f489ce62fedf979ccc08361641', 'v0.0.307'),
-    ('preresnet101', '0575', 'e2887e539f2519c36aea0fc991d6503ed384c4fc', 'v0.0.2'),
+    ('preresnet101', '0534', 'ea9a1724662744fe349c0aa8dd0ec42708fe88c7', 'v0.0.504'),
     ('preresnet101b', '0540', '3839a4733a8a614bb6b7b4f555759bb5b8013d42', 'v0.0.351'),
-    ('preresnet152', '0532', '31505f719ad76f5aee59d37a695ac7a9b06230fc', 'v0.0.14'),
-    ('preresnet152b', '0500', '6929c862634ff7a7ac2317ab5e97bd1c62dc3278', 'v0.0.386'),
-    ('preresnet200b', '0564', '38f849a61f59924d85a9353923424889a77c93dc', 'v0.0.45'),
-    ('preresnet269b', '0556', 'f386e3e70ab4df48fd8b444858bd6acd8afcbe6b', 'v0.0.239'),
+    ('preresnet152', '0446', '3b41bd93a7a2807e8cc88ae75ec0cde69af1e786', 'v0.0.510'),
+    ('preresnet152b', '0438', 'ebf71d023e88d006c55946e3c6cf38c5d0cffeb2', 'v0.0.523'),
+    ('preresnet200b', '0446', '70135e6618bd8e870574a2667d3ec592238b3a3c', 'v0.0.529'),
+    ('preresnet269b', '0501', '6e56119dc52a38af690bb41d4ae1683007558233', 'v0.0.545'),
     ('resnext14_16x4d', '1223', '1f8072e8d01d1427941a06bbca896211e98e2b75', 'v0.0.370'),
     ('resnext14_32x2d', '1247', '2ca8cc2544045c21d0a7ca740483097491ba0855', 'v0.0.371'),
     ('resnext14_32x4d', '1110', '9be6190e328c15a06703be3ba922d707c2f4d8e7', 'v0.0.327'),
     ('resnext26_32x2d', '0850', 'a1fb4451be6336d9f648ccc2c2dedacc5704904a', 'v0.0.373'),
     ('resnext26_32x4d', '0721', '5264d7efd606e1c95a2480050e9f03a7a2f02b09', 'v0.0.332'),
-    ('resnext50_32x4d', '0546', 'd0ae6b111b6c973c9057b7b762930bba9bfe32fb', 'v0.0.417'),
-    ('resnext101_32x4d', '0492', 'c31cce1c38e8017ae97519a0eb721e65722d8fc2', 'v0.0.417'),
-    ('resnext101_64x4d', '0483', '44b79943cd9050e2703c169364334b458a8ade89', 'v0.0.417'),
-    ('seresnet10', '1329', 'af28e6d02954a9be6c3cec2e48021583755f1756', 'v0.0.354'),
+    ('resnext50_32x4d', '0545', '748e53b31fe716b5fdd059107d22bdfec3a31839', 'v0.0.498'),
+    ('resnext101_32x4d', '0418', 'c07faa66647bd25dd222b44d8782c59fcc2e3708', 'v0.0.530'),
+    ('resnext101_64x4d', '0439', '178e79057f27afec04219aa1a1a96abbbd8763a9', 'v0.0.544'),
+    ('seresnet10', '1169', '675d4b5bbaaab1b87988df96819cd19e5323512c', 'v0.0.486'),
+    ('seresnet12', '1176', 'df10dd88759750bb042ce7b09dd8a78f32d78e12', 'v0.0.544'),
+    ('seresnet14', '1095', '579e2fecfe37d1c9422f6521fef610bfde6fcaaa', 'v0.0.545'),
+    ('seresnet16', '0972', 'ef50864856c2120082e3db7d4193f31ec77624c6', 'v0.0.545'),
     ('seresnet18', '0920', '85a6b1da19645419cc3075852588cc7e7da5715f', 'v0.0.355'),
     ('seresnet26', '0803', '9f9004192240ae0125399d2f6acbb5359027039d', 'v0.0.363'),
     ('seresnetbc26b', '0682', '15ae6e19b1626107029df18bf3f5140e6fcb2b02', 'v0.0.366'),
     ('seresnetbc38b', '0575', 'f80f0c3c2612e1334204df1575b8a7cd18f851ff', 'v0.0.374'),
     ('seresnet50', '0560', 'e75ef498abfc021f356378b2c806de8927287fe7', 'v0.0.441'),
     ('seresnet50b', '0533', '0d8f0d23bb980621095e41de69e3a68d7aaeba45', 'v0.0.387'),
-    ('seresnet101', '0589', '4c10238dd485a540a464bf1c39a8752d2da040b9', 'v0.0.11'),
+    ('seresnet101', '0441', 'f9cb9df623683520522c5fe8577e8a93cf253f46', 'v0.0.533'),
     ('seresnet101b', '0462', '59fae71a5db6ad1f1b5a79f7339920aa1191ed70', 'v0.0.460'),
-    ('seresnet152', '0577', 'de6f099dd39f374390639ca8854b2954af3c59b9', 'v0.0.11'),
-    ('sepreresnet10', '1306', 'cbdd10532dd79915228f12624577c58a2daa078d', 'v0.0.377'),
-    ('sepreresnet18', '0938', 'f9645ed3b56b85778dc697dc7749851d14e3564a', 'v0.0.380'),
+    ('seresnet152', '0430', 'c712f55410938861c32740fe93770b0d54e094a3', 'v0.0.538'),
+    ('sepreresnet10', '1221', 'c3ab94ee5c938f53a8a61849be3a463458444a1f', 'v0.0.544'),
+    ('sepreresnet12', '1180', 'd6b7260b4931e8806368c42b8bb605b9a8afaa23', 'v0.0.543'),
+    ('sepreresnet16', '0956', 'b5e4e06f6f5394f7557986193700a8ecf23ffdc7', 'v0.0.543'),
+    ('sepreresnet18', '0881', 'b018c6e38601b0719445e302ea64196924319814', 'v0.0.543'),
+    ('sepreresnet26', '0804', 'a2e48457a44958ed7f20940997f419080b1d14e8', 'v0.0.543'),
     ('sepreresnetbc26b', '0636', '33c94c9dd2986d0643f7c432d5203294ecf2124e', 'v0.0.399'),
     ('sepreresnetbc38b', '0563', 'd8f0fbd35b840743e312b9ec944c7fc141824ace', 'v0.0.409'),
     ('sepreresnet50b', '0532', '5b620ff7175c674ef41647e2e79992dceefeec19', 'v0.0.461'),
-    ('seresnext50_32x4d', '0505', '7f3fae1ff9d2774fa36067703c28fd57708889f2', 'v0.0.418'),
-    ('seresnext101_32x4d', '0460', '6cb1ee646fdd47b745ffa09e0e8ecfec3ce695a3', 'v0.0.418'),
+    ('seresnext50_32x4d', '0433', 'd74d1d0a5bd1449562e9f1de92b1389c647fdd13', 'v0.0.505'),
+    ('seresnext101_32x4d', '0444', '3c89aec5b98c1bfca13bc8c21e07dba82243c012', 'v0.0.529'),
     ('seresnext101_64x4d', '0466', '15e1673077240a648027505540fc893a68401e87', 'v0.0.418'),
     ('senet16', '0806', 'ba26802160725af926e5a3217f8848bd3a6599fd', 'v0.0.341'),
     ('senet28', '0591', 'd5297a35a2e56ecc892499c1bd4373125a40b783', 'v0.0.356'),
-    ('senet154', '0465', 'dd2445078c0770c4a52cd22aa1d4077eb26f6132', 'v0.0.13'),
-    ('resnestabc14', '0729', 'cba0b049a07ada6ec336e6cdeaf9aefdc0633d4b', 'v0.0.465'),
-    ('resnesta18', '0732', 'f970799093ef1453a98b2f403a90ea48b349fe6e', 'v0.0.471'),
-    ('resnestabc26', '0562', 'b5edf7c1ebed884afb129f4b7ffc5a480156a044', 'v0.0.465'),
-    ('resnesta50', '0451', '445a013a228b65a3e626fe71710ebd1c8350843a', 'v0.0.465'),
+    ('senet154', '0440', 'c0e2d2b9e70894e28e4f957296229bdd89b70607', 'v0.0.522'),
+    ('resnestabc14', '0634', '4b0cbe8c59e9d764027f51670096037e2f058970', 'v0.0.493'),
+    ('resnesta18', '0689', '8f37b6927751b27a72c1b8c625de265da9b31570', 'v0.0.489'),
+    ('resnestabc26', '0470', 'f88d49d7bd6cdf1f448afdf4bc5dadd9921798dd', 'v0.0.495'),
+    ('resnesta50', '0438', '6ce54a97d6e6fe8aa66755669b8f47a0790bfeb6', 'v0.0.531'),
     ('resnesta101', '0399', 'ab6c6f89407d7b2cf89406f7bb62a48e86d7cabc', 'v0.0.465'),
+    ('resnesta152', '0451', '532c448de0011e90924b3c1e829f9525c6a5420e', 'v0.0.540'),
     ('resnesta200', '0340', '3bd1f0c8d9a2862b89590c1c490a38d6d982522c', 'v0.0.465'),
     ('resnesta269', '0336', '8333862a0c016432f6cd5b45f7e9de7ee6e3f319', 'v0.0.465'),
-    ('ibn_resnet50', '0668', 'db527596f81f5b4aa1f0c490bf0ef5cfeef5fb76', 'v0.0.127'),
+    ('ibn_resnet50', '0559', '0f75710a144ea1483e6235f6909f8b8c3555ec01', 'v0.0.495'),
     ('ibn_resnet101', '0587', '946e7f1072a70b19f2bbc9776f73b818473482c3', 'v0.0.127'),
     ('ibnb_resnet50', '0697', '0aea51d29d4123676e447b92db800f5a574a35be', 'v0.0.127'),
     ('ibn_resnext101_32x4d', '0562', '05ddba79597927b5c0fa516d435c3788803438f6', 'v0.0.127'),
-    ('ibn_densenet121', '0747', '1434d379777ff6b61469f7adc6ed73919da94f02', 'v0.0.127'),
-    ('ibn_densenet169', '0682', '6d7c48c5519c6b8595223514564b1061268742a2', 'v0.0.127'),
-    ('airnet50_1x64d_r2', '0621', '347358cc4a3ac727784665e8113cd11bfa79c606', 'v0.0.120'),
-    ('airnet50_1x64d_r16', '0646', '0b847b998253ba22409eed4b939ec2158928a33f', 'v0.0.120'),
-    ('airnext50_32x4d_r2', '0575', 'ab104fb5225b17836d523a525903db254f5fdd99', 'v0.0.120'),
-    ('bam_resnet50', '0696', '7e573b617562d7dab94cda3b1a47ec0085aaeba2', 'v0.0.124'),
-    ('cbam_resnet50', '0638', '78be56658e9f9452d7c2472c994b332d97807a17', 'v0.0.125'),
-    ('scnet50', '0640', 'f3aff16f4734f8563f1236a4688edf18c96de8c1', 'v0.0.472'),
-    ('scnet101', '0599', '8c30a4c7b0b5bfb36485ee5106648436ab8df9e3', 'v0.0.472'),
-    ('scneta50', '0463', '4b2031a8bcc69523f1da8af7ad52b69795d2f965', 'v0.0.472'),
-    ('regnetx002', '1133', '988616daf305fd03401a289b1e63574512ced7c1', 'v0.0.473'),
-    ('regnetx004', '0909', 'f01b9591f96d33f567a7a2da39661e4349054e3d', 'v0.0.473'),
-    ('regnetx006', '0816', 'bddeeb9bdb31f4feb0a221a2eb3cccd82db5ea78', 'v0.0.473'),
-    ('regnetx008', '0763', '1cd8ff6500ed489871e2a9d2baff20526782d981', 'v0.0.473'),
-    ('regnetx016', '0648', 'a8bd522863c5024486ef0e37c91b2408ae2cfd74', 'v0.0.473'),
-    ('regnetx032', '0585', '4bca3dd83b8aeec029fa8b9b0606e80ed6ec1114', 'v0.0.473'),
-    ('regnetx040', '0578', 'ffd9ffe46e125afa8544706333ff6ebcd4cbc10e', 'v0.0.473'),
-    ('regnetx064', '0541', 'd9c902de21804f6f6df3e31ce8ee0b30e86d0821', 'v0.0.473'),
-    ('regnetx080', '0545', '7eb99b19aed61972bb834b798523f0a84a2ea341', 'v0.0.473'),
-    ('regnetx120', '0522', '22c6c13843884293f13be2d86f3087ba796258d3', 'v0.0.473'),
-    ('regnetx160', '0505', 'f2dac945f02a1af1b9751a3e4531e66c68a4cb98', 'v0.0.473'),
-    ('regnetx320', '0489', '80ef5db7027fdadd3e6b61e67de300d6b0e68f2f', 'v0.0.473'),
-    ('regnety002', '1038', '8cd4e5be6e20a5d685e93980fedd675a44a8d876', 'v0.0.473'),
-    ('regnety004', '0808', 'd294633343b67bab60418e8acba372b1445817e2', 'v0.0.473'),
-    ('regnety006', '0726', 'c89640250cdb05e9f8f7587598bce2f07477301d', 'v0.0.473'),
-    ('regnety008', '0687', 'eb3edfbf5a92d8adbb33193253fb0b1561c3c441', 'v0.0.473'),
-    ('regnety016', '0616', '07592e6c3bd8a7fb8301750c343c92c69ea8cdbb', 'v0.0.473'),
+    ('ibn_densenet121', '0646', '82ee3ff44fd308107ec07d759c52a99e94af7041', 'v0.0.493'),
+    ('ibn_densenet169', '0608', 'b509f33947b2f205f03e49ce2d5ee87855bbf708', 'v0.0.500'),
+    ('airnet50_1x64d_r2', '0523', '1f982e0e8b3af40a5d67ca854f18ca837aa332f4', 'v0.0.522'),
+    ('airnet50_1x64d_r16', '0544', '09a9f13b9d5f3e27eb26271070cc4bf8dd72cf9f', 'v0.0.519'),
+    ('airnext50_32x4d_r2', '0504', '664dd077a978562a376e8ab70b5d740893873111', 'v0.0.521'),
+    ('bam_resnet50', '0538', 'fa612c3da552cd26094634c359413db69d0ef97b', 'v0.0.499'),
+    ('cbam_resnet50', '0488', 'ebd4af235d763f4ecce6dd4e09b508ba61b561f7', 'v0.0.537'),
+    ('scnet50', '0511', '359d35d017e838d3c3c2bdf1cc83074610dc3c5b', 'v0.0.493'),
+    ('scnet101', '0446', 'bc5cade042e78813db4ce5878d733daa0ce7f89d', 'v0.0.507'),
+    ('scneta50', '0459', 'c1f6f0286ed942bbc468395b82b7be84312f3c73', 'v0.0.509'),
+    ('regnetx002', '1038', '7800b310f45b4666ef6c862bc8a2573f65ddaa40', 'v0.0.475'),
+    ('regnetx004', '0855', 'b933a72fe7304a31391a9e9fcdf7ffc47ea05353', 'v0.0.479'),
+    ('regnetx006', '0756', 'd41aa087bd288266105142b88b03b67d74352a46', 'v0.0.482'),
+    ('regnetx008', '0724', '79309908dee31eda64e824a9b3bd33c0afaaf5a8', 'v0.0.482'),
+    ('regnetx016', '0613', '018dbe2d89d2bac26f41d98b09ba57b049ed4cfe', 'v0.0.486'),
+    ('regnetx032', '0568', '6d4372fcf0b9d6e3edefa99e72dd411b6a0c676c', 'v0.0.492'),
+    ('regnetx040', '0469', 'c22092c7ceeac713a9102c697f23bec0b7cfaec0', 'v0.0.495'),
+    ('regnetx064', '0458', '473342937e02dce6244a62780f98aed1f5eb831d', 'v0.0.535'),
+    ('regnetx080', '0466', '4086910ad9df1693db658c86f874f686a279175c', 'v0.0.515'),
+    ('regnetx120', '0518', 'ea20b368214230ce65c14218aedba07b68235e38', 'v0.0.542'),
+    ('regnetx160', '0456', '941840a38b20e5b5c6ca092bed3f2ea0ff602895', 'v0.0.532'),
+    ('regnetx320', '0394', 'a120c8d2d181dacffde8a3029292ee59da12e9be', 'v0.0.548'),
+    ('regnety002', '0953', 'b37fcac05e59ba5e751701da8e81195bbfbf3db8', 'v0.0.476'),
+    ('regnety004', '0747', '5626bdf45eaf0f23ddc6e1b68f6ad2db7ca119cf', 'v0.0.481'),
+    ('regnety006', '0697', '81372679b5f9601a5bc72caa13aff378d2ac4233', 'v0.0.483'),
+    ('regnety008', '0645', 'd92881be768a267f1cd2b540d087884bbe93f644', 'v0.0.483'),
+    ('regnety016', '0568', 'c4541a25e92ebf31d9bddb4975738c08fe929836', 'v0.0.486'),
     ('regnety032', '0413', '9066698526cbc930706fe00b21ca56c31ad7e2e4', 'v0.0.473'),
-    ('regnety040', '0537', '523ecd34776ba4ad3368cd020ad4f33f6419aa85', 'v0.0.473'),
-    ('regnety064', '0512', '66d05225c4c7a77c8add4c7fd3784fb3253a41da', 'v0.0.473'),
-    ('regnety080', '0509', '687183a2b431c9fa5cf536cbe884eaefaef57e59', 'v0.0.473'),
-    ('regnety120', '0482', '0946781aa91bef0f89307f33defdac7d5f385861', 'v0.0.473'),
-    ('regnety160', '0497', 'e458ce58977d36ffb48043853a65e471c4a100c2', 'v0.0.473'),
-    ('regnety320', '0458', '900b95919cafc18d2a3404dcbe89e008f44170c2', 'v0.0.473'),
-    ('pyramidnet101_a360', '0652', '08d5a5d1af3d514d1114ce76277223e8c1f5f426', 'v0.0.104'),
+    ('regnety040', '0467', '6039a215ee79a7855156c5166df4c6b34f8d501d', 'v0.0.494'),
+    ('regnety064', '0445', '8ae16f971eacad369df091e68c26e63b8c6da9a5', 'v0.0.513'),
+    ('regnety080', '0436', '4cd7fc61d54ec63bfeff11246e8258188351e7ed', 'v0.0.516'),
+    ('regnety120', '0431', 'effa35b601ffbdced20342d9bfe3917a8279880a', 'v0.0.526'),
+    ('regnety160', '0430', '8273156944dea5a439ef55e7ed84a10524be090c', 'v0.0.527'),
+    ('regnety320', '0427', 'c3ed45966565fe2167591aef7a33804d954aa202', 'v0.0.548'),
+    ('pyramidnet101_a360', '0520', '3a98a2bfc4e74b00b5fff20783613281121a6d37', 'v0.0.507'),
     ('diracnet18v2', '1117', '27601f6fa54e3b10d77981f30650d7a9d4bce91e', 'v0.0.111'),
     ('diracnet34v2', '0946', '1faa6f1245e152d1a3e12de4b5dc1ba554bc3bb8', 'v0.0.111'),
     ('crunet56', '0825', 'ad16523bfa306aefae5f931ed3bd6d01cd6d1804', 'v0.0.197'),
@@ -151,59 +158,67 @@ _model_sha1 = {name: (error, checksum, repo_release_tag) for name, error, checks
     ('densenet201', '0590', '89aa8c295b21fdd682df0027d2232e6dabf2cace', 'v0.0.426'),
     ('condensenet74_c4_g4', '0864', 'cde68fa2fcc9197e336717a17753a15a6efd7596', 'v0.0.4'),
     ('condensenet74_c8_g8', '1049', '4cf4a08e7fb46f5821049dcae97ae442b0ceb546', 'v0.0.4'),
-    ('peleenet', '1125', '38d4fb245659a54204ca8f3562069b786eace1b1', 'v0.0.141'),
-    ('wrn50_2', '0612', 'f8013e680bf802301e6830e5ca12de73382edfb1', 'v0.0.113'),
-    ('drnc26', '0789', 'ee56ffabbcceba2e4063c80a3f84a4f4f8461bff', 'v0.0.116'),
+    ('peleenet', '0979', '758d3cf992a6c92731069be091be2e8ebd3209e2', 'v0.0.496'),
+    ('wrn50_2', '0606', '5ff344cae22c8ce3f21e042be5a5d899681d89a0', 'v0.0.520'),
+    ('drnc26', '0711', 'e69a4e7bc94aab58e05880c886e8e829584845c3', 'v0.0.508'),
     ('drnc42', '0692', 'f89c26d6a3792bef0850b7fe09ee10f715dcd3ce', 'v0.0.116'),
     ('drnc58', '0627', '44cbf15ccaea33ee1e91b780e70170e8e66b12d7', 'v0.0.116'),
-    ('drnd22', '0852', '085747529f2d4a0490769e753649843c40dea410', 'v0.0.116'),
+    ('drnd22', '0744', 'aecf15fc2171d29d8ea765afa540e4ddb40a9b19', 'v0.0.498'),
     ('drnd38', '0736', 'c7d53bc0f70196dda589fcf0bfac904b5d76d872', 'v0.0.116'),
     ('drnd54', '0627', '87d44c87953d98241f85007802a61e3cefd77792', 'v0.0.116'),
     ('drnd105', '0581', 'ab12d66220c1bbf4af5c33db78aaafc9f0d9bd5a', 'v0.0.116'),
     ('dpn68', '0658', '07251919c08640c94375670cbc5f0fbc312ed59b', 'v0.0.310'),
-    ('dpn98', '0528', 'fa5d6fca985afde21f6374e4a4d4df788d1b4c3a', 'v0.0.17'),
-    ('dpn131', '0522', '35ac2f82e69264e0712dcb979da4d99675e2f2aa', 'v0.0.17'),
+    ('dpn98', '0422', '1ace57dc702d5b6ca7eccb657036f682605d7efc', 'v0.0.540'),
+    ('dpn131', '0477', 'e814a53cc6cddc0b6f2a11393a88c44723a8ec0c', 'v0.0.534'),
     ('darknet_tiny', '1746', '16501793621fbcb137f2dfb901760c1f621fa5ec', 'v0.0.69'),
     ('darknet_ref', '1668', '3011b4e14b629f80da54ab57bef305d588f748ab', 'v0.0.64'),
-    ('darknet53', '0556', 'e9486353868e0cf78bdc8fa377437de4d02733bb', 'v0.0.150'),
+    ('darknet53', '0550', '1d0b4f620071d544a3a1ccbe437267b8925ecc63', 'v0.0.501'),
     ('irevnet301', '0897', 'cef9b5bfe9dd51c7d7946de432fd358f54239d35', 'v0.0.251'),
     ('bagnet9', '3544', 'ea1ae64532fc58e4efe585b3154aa4b42a677d77', 'v0.0.255'),
     ('bagnet17', '2152', '4b3a621287346dc836fe42de0b0888fb9a1c9075', 'v0.0.255'),
     ('bagnet33', '1495', '87527d8247b62bccfdd76a9d5e6e914ebfa5362a', 'v0.0.255'),
-    ('dla34', '0821', '1127fa0a270ed5fe1112d9039cf44ee06ac18817', 'v0.0.202'),
+    ('dla34', '0705', '557c5f4f1db66481af6101c75d9ba52b486eda25', 'v0.0.486'),
     ('dla46c', '1286', '5b38b67fecf2d701b736eb23e1301b6dd7eb5fb9', 'v0.0.282'),
     ('dla46xc', '1225', 'e570f5f00a098b0de34e657f9d8caeda524d39f3', 'v0.0.293'),
-    ('dla60', '0708', '954571d6917a836cb3433b664fd1b8330955c0fa', 'v0.0.202'),
-    ('dla60x', '0621', '35774214758743caeae249482bcf8a0ab8caf456', 'v0.0.202'),
+    ('dla60', '0554', '88b141c4ca81598dbe4333bd4ddd5a1554772348', 'v0.0.494'),
+    ('dla60x', '0553', '58924af84faf6ac0d980b047ccb505619925d97d', 'v0.0.493'),
     ('dla60xc', '1074', '1b4e4048847e1ba060eb76538ee09e760f40be11', 'v0.0.289'),
-    ('dla102', '0644', 'cadbb1cc5feb58497198aac2c8028c843a6d5a9f', 'v0.0.202'),
-    ('dla102x', '0602', '193568a7ab3c0a3b6702fcc3e326b7fef011f752', 'v0.0.202'),
-    ('dla102x2', '0553', '30c8f409240872053c5bb8523baeb274ba9da4ee', 'v0.0.202'),
-    ('dla169', '0587', '4f3e6a6e604cc06ebcf63fc86cc5287399f32683', 'v0.0.202'),
-    ('fishnet150', '0638', '5cbd08ec1534f2d5e7861395cc6f224ecbe8cb76', 'v0.0.168'),
+    ('dla102', '0517', '0e5d954cee3bb260a679425524deab61871bd0bf', 'v0.0.505'),
+    ('dla102x', '0470', 'ea82787ce2b3c79cff32ccf54461507cc09c58ce', 'v0.0.528'),
+    ('dla102x2', '0423', 'dde259b3525fb6dae7e445f6e534a13159b3b365', 'v0.0.542'),
+    ('dla169', '0460', '71971da4e881084851c9b581e719ce4edfb8292d', 'v0.0.539'),
+    ('fishnet150', '0466', 'ed21862d14bb0a4e9d1723b7c639e455a7b141c0', 'v0.0.502'),
     ('espnetv2_wd2', '2107', 'f2e17f0a8845b72f4645a0c06f2cfc8d9ef0253e', 'v0.0.238'),
     ('espnetv2_w1', '1427', '538f31fb92699fddabc27784fe746871fd8a635b', 'v0.0.238'),
     ('espnetv2_w5d4', '1273', 'b119ad9e52bf8c2d88db8eeb62a1fd6e23a1b6a6', 'v0.0.238'),
-    ('espnetv2_w3d2', '1194', '3804a85006d874273b80026339b36943e9d813e5', 'v0.0.238'),
+    ('espnetv2_w3d2', '1135', 'efd55816603c12622256a4c72f30de027f5943b8', 'v0.0.520'),
     ('espnetv2_w2', '0994', 'c212d81a9d12361b7d49ec841599f6a0f84f7b44', 'v0.0.238'),
-    ('hrnet_w18_small_v1', '0975', 'fb7868dfb831cb6dc2cdce03ef982cd253eede5f', 'v0.0.421'),
-    ('hrnet_w18_small_v2', '0802', '052ff8f941529378a3f6a9885e8e5232f9d2b992', 'v0.0.421'),
-    ('hrnetv2_w18', '0685', '21c708c4144246058c4346d9296f6d180682af99', 'v0.0.421'),
-    ('hrnetv2_w30', '0607', '93553fe4cccd22afaac7f73937b98e8ac89850cd', 'v0.0.421'),
-    ('hrnetv2_w32', '0607', 'e68bcf9079982540f80607d7fb1331594f721fd6', 'v0.0.421'),
-    ('hrnetv2_w40', '0571', '60aa3b9d3a91d20535753fcef0d668aeae466b10', 'v0.0.421'),
-    ('hrnetv2_w44', '0592', 'ff313e2963d1464251f5dbb7032502ffd028d612', 'v0.0.421'),
-    ('hrnetv2_w48', '0578', '8823f8445b793c8ab5d1f2dd772978c2a71b7850', 'v0.0.421'),
-    ('hrnetv2_w64', '0552', '3d8ef6e5f59fbce8746b9e658b568be9236df21a', 'v0.0.421'),
-    ('vovnet39', '0689', '160cdb6d7579a8cb740090b1bf72ac1a365146ae', 'v0.0.431'),
-    ('vovnet57', '0660', 'f4f3ed330c374008498ba34ca7f54759a40ac1ba', 'v0.0.431'),
-    ('selecsls42b', '0678', '7d223ce87f01618f80fa0d8a15e6921b62dd2efb', 'v0.0.430'),
-    ('selecsls60', '0633', '863775945c8f3697419e52e403b113040bf6ee6f', 'v0.0.430'),
-    ('selecsls60b', '0600', 'aaa7579483fede7ddece283da3bd6733e0a991e8', 'v0.0.430'),
-    ('hardnet39ds', '1004', '9452be3ea868a396a6c5e13e28061254e4657b08', 'v0.0.435'),
-    ('hardnet68ds', '0847', '0962e9a5fcb853a3c7c32e481b940fe39db20cf1', 'v0.0.435'),
-    ('hardnet68', '0736', '84d17675ad7c8a181c6d5b7484684c9ecf1347d2', 'v0.0.435'),
-    ('hardnet85', '0642', '00c005ce6616cfebc0ddadd75f11a94e6363d081', 'v0.0.435'),
+    ('dicenet_wd5', '3067', 'e7d011943764bb73e409f13948f933d7dd7a4217', 'v0.0.497'),
+    ('dicenet_wd2', '2370', 'add0bc225414bada5ec847c54c230c9a1cc42f3f', 'v0.0.497'),
+    ('dicenet_w3d4', '1647', '7200f0a35cae789ee223351ae4c6c67642eb6816', 'v0.0.497'),
+    ('dicenet_w1', '1411', '93e2e0df3b9cb62c8ba08d3f3d61237e20fce9e2', 'v0.0.513'),
+    ('dicenet_w5d4', '1251', '710737608fb6e2282cdd3903d4a703eb1989b594', 'v0.0.515'),
+    ('dicenet_w3d2', '1144', 'bb2a902d7adbe96472157e131153f48dfea9f37f', 'v0.0.522'),
+    ('dicenet_w7d8', '1081', '37b9276b8b97c87554652d6963a566cbd189b054', 'v0.0.527'),
+    ('dicenet_w2', '1058', '66980b52c10eb72e0f254edfc1045f48f627eb37', 'v0.0.497'),
+    ('hrnet_w18_small_v1', '0873', '1060c1c562770adb94115de1cad797684dbb5703', 'v0.0.492'),
+    ('hrnet_w18_small_v2', '0602', '1f319e1b1990818754b97104467cfecf3401ae4e', 'v0.0.499'),
+    ('hrnetv2_w18', '0500', '0a70090294c726c1f303e9114d23c9373695eb44', 'v0.0.508'),
+    ('hrnetv2_w30', '0508', 'eb6afc492537295615dc465236934a9a970c1bef', 'v0.0.525'),
+    ('hrnetv2_w32', '0496', '9c6c47dcce100ff006509ed559158862a53436a6', 'v0.0.528'),
+    ('hrnetv2_w40', '0481', '2382694cceff60b32b4702e64945706f183e3e1c', 'v0.0.534'),
+    ('hrnetv2_w44', '0486', 'f5882024ac9513c2d6c2b41bc774862e392f69ad', 'v0.0.541'),
+    ('hrnetv2_w48', '0484', '936bb78f8c187ca3cc96c7564fa3ff8ad9cb68a6', 'v0.0.541'),
+    ('hrnetv2_w64', '0478', '4c18c51411db532c3b8168f0a1ae3e461e703d68', 'v0.0.543'),
+    ('vovnet39', '0548', '20b60ee6bb8c59c684f8ffed7fbda3d76b1a7280', 'v0.0.493'),
+    ('vovnet57', '0510', 'ed3cad779b94c4f4f531d6c37f90f1a5209d3b1c', 'v0.0.505'),
+    ('selecsls42b', '0596', 'f5a35c74880fbe94fbe3770a96968fc81186b42b', 'v0.0.493'),
+    ('selecsls60', '0511', '960edec5159b56bdba4ce606df203c8ce14cb8ba', 'v0.0.496'),
+    ('selecsls60b', '0537', '7f83801b1c158502d93a4523bdecda43017448d5', 'v0.0.495'),
+    ('hardnet39ds', '0864', '72e8423ee0b496c10b48ae687a417385d9667394', 'v0.0.485'),
+    ('hardnet68ds', '0738', '012bf3ac31f38c78d5cdef1367cc3c27447236af', 'v0.0.487'),
+    ('hardnet68', '0710', 'c8d4c059f2688f0005a7cd1160ac0fbf093b69cd', 'v0.0.491'),
+    ('hardnet85', '0572', '3baa0a7dd204196fd1afa631cf6de082a5cc0a36', 'v0.0.495'),
     ('squeezenet_v1_0', '1734', 'e6f8b0e8253cef1c5c071dfaf2df5fdfc6a64f8c', 'v0.0.128'),
     ('squeezenet_v1_1', '1739', 'd7a1483aaa1053c7cd0cf08529b2b87ed2781b35', 'v0.0.88'),
     ('squeezeresnet_v1_0', '1767', '66474b9b6a771055b28c37b70621c026a1ef6ef4', 'v0.0.178'),
@@ -245,10 +260,10 @@ _model_sha1 = {name: (error, checksum, repo_release_tag) for name, error, checks
     ('mobilenet_wd2', '1330', '94f13ae1375b48892d8ecbb4a253bb583fe27277', 'v0.0.156'),
     ('mobilenet_w3d4', '1051', '6361d4b4192b5fc68f3409100d825e8edb28876b', 'v0.0.130'),
     ('mobilenet_w1', '0865', 'eafd91e9369abb09726f2168aba24453b17fc22e', 'v0.0.155'),
-    ('mobilenetb_wd4', '2267', 'a13205ec1f2c20be548dad6523393ee877e84870', 'v0.0.467'),
-    ('mobilenetb_wd2', '1324', '2c2319248f033fb730a4d64f00ccc151d8417eff', 'v0.0.464'),
-    ('mobilenetb_w3d4', '1039', 'f7bf24756a626fccf81980352c45b68aa67fc16d', 'v0.0.467'),
-    ('mobilenetb_w1', '0908', '60fe12ca8c4a8824c49d14a5e8e1a7876ea3c75c', 'v0.0.466'),
+    ('mobilenetb_wd4', '2165', '2070764e0b3be74922eb5fa0a4342c693821ba90', 'v0.0.481'),
+    ('mobilenetb_wd2', '1271', '799ef980b2726a77d4b68d99f520d9d6bc7d86dc', 'v0.0.480'),
+    ('mobilenetb_w3d4', '1020', 'b01c8bacda6f8e26b34a0313a4dc3883511760f7', 'v0.0.481'),
+    ('mobilenetb_w1', '0788', '82664eb4c1f2ddd0ac163f50263237f7667223f3', 'v0.0.489'),
     ('fdmobilenet_wd4', '3053', 'd4f18e5b4ed63e5426eafbf5db7f8e2a97c28581', 'v0.0.177'),
     ('fdmobilenet_wd2', '1969', '242b9fa82d54f54f08b4bdbb194b7c89030e7bc4', 'v0.0.83'),
     ('fdmobilenet_w3d4', '1601', 'cb10c3e129706d3023d752e7402965af08f91ca7', 'v0.0.159'),
@@ -257,32 +272,32 @@ _model_sha1 = {name: (error, checksum, repo_release_tag) for name, error, checks
     ('mobilenetv2_wd2', '1442', 'd7c586c716e3ea85e793f7c5aaf9cae2a907117b', 'v0.0.170'),
     ('mobilenetv2_w3d4', '1044', '768454f4bdaae337c180bb81248b8c5b8d31040b', 'v0.0.230'),
     ('mobilenetv2_w1', '0864', '6e58b1cb96852e4c6de6fc9cd11241384af21df9', 'v0.0.213'),
-    ('mobilenetv2b_wd4', '2510', '71f5f8ea3e59880f07e4153e7d5dd2148b3024a0', 'v0.0.453'),
-    ('mobilenetv2b_wd2', '1469', 'd5dc39103bbe86ded78007635d3bd11907d8459a', 'v0.0.453'),
-    ('mobilenetv2b_w3d4', '1150', '95b6171a0a117d7e8c7b79532b7d1cdde9ff52ac', 'v0.0.453'),
-    ('mobilenetv2b_w1', '0943', 'c53fbfeb34194fe18a599b753575f4d1a95a2774', 'v0.0.453'),
-    ('mobilenetv3_large_w1', '0769', '7f4b9203ecfc52ba7bccdfc0b44daf0edd3cee7c', 'v0.0.411'),
+    ('mobilenetv2b_wd4', '2338', '77ba7e8d41542d311e240dab75e4d29fa0677fb9', 'v0.0.483'),
+    ('mobilenetv2b_wd2', '1373', '3bfc8a592a0881c2cb025f52a09fb5057a7896be', 'v0.0.486'),
+    ('mobilenetv2b_w3d4', '1064', '5d4dc4e5622043697382272183a3d0bd43dbc218', 'v0.0.483'),
+    ('mobilenetv2b_w1', '0884', 'ab0ea3993e7c533f0aea5793331dc6302d715e9c', 'v0.0.483'),
+    ('mobilenetv3_large_w1', '0729', 'db741a9938acc8a5fd9544aaf53b41aebb98e021', 'v0.0.491'),
     ('igcv3_wd4', '2830', '71abf6e0b6bff1d3a3938bfea7c752b59ac05e9d', 'v0.0.142'),
     ('igcv3_wd2', '1703', '145b7089e1d0e0ce88f17393a357d5bb4ae37734', 'v0.0.132'),
     ('igcv3_w3d4', '1096', '3c7c86fc43df2e5cf95a451ebe07fccf2d9dc076', 'v0.0.207'),
     ('igcv3_w1', '0900', 'e2c3da1cffd8e42da7a052b80db2f86758c8d35b', 'v0.0.243'),
-    ('mnasnet_b1', '0800', '5a8d0e0ca03f56b1d1c4d27bfb1217f2631c4138', 'v0.0.419'),
-    ('mnasnet_a1', '0755', '3731d8dbb9334b55597028061dde93a7403e60a6', 'v0.0.419'),
-    ('darts', '0897', 'aafd645210df6b55587ef02f4edf08c76a15e5a3', 'v0.0.118'),
+    ('mnasnet_b1', '0723', 'a6f74cf912fa5b1ee4bb9825f3143a0c1ced03be', 'v0.0.493'),
+    ('mnasnet_a1', '0705', '3efe98a3bd6ea0a8cb0902a4dba424c134145d5f', 'v0.0.486'),
+    ('darts', '0756', 'c2c7c33ba60d1052f95bcae72128fc47b1214cff', 'v0.0.485'),
     ('proxylessnas_cpu', '0750', '256da7c8a05cd87a59e30e314b22dc1d4565946e', 'v0.0.324'),
     ('proxylessnas_gpu', '0724', 'd9ce80964e37fb30bddcc552f1d68361b1a94873', 'v0.0.333'),
     ('proxylessnas_mobile', '0780', 'b8bb5a64f333562475dcfc09eeb7e603d6e66afb', 'v0.0.326'),
     ('proxylessnas_mobile14', '0651', 'f08baec85343104994b821581cde3ee965a2c593', 'v0.0.331'),
-    ('fbnet_cb', '0786', '5e8f8775196c8395d9c5ca042ca8f28164e42563', 'v0.0.415'),
-    ('xception', '0556', 'bd2c1684a5dc41dd00b4676c194a967558ed577e', 'v0.0.115'),
+    ('fbnet_cb', '0761', '3db688f2fa465bc93bc546b4432389fe33aec5b3', 'v0.0.486'),
+    ('xception', '0511', '9755eb77589d627d816fe9806a2b2aa931b6c2f6', 'v0.0.544'),
     ('inceptionv3', '0559', '6c087967685135a321ed66b9ad2277512e9b2868', 'v0.0.92'),
-    ('inceptionv4', '0525', 'f7aa9536392ea9ec7df5cc8771ff53c19c45fff2', 'v0.0.105'),
-    ('inceptionresnetv2', '0494', '3328f7fa4c50c785b525e7b603926ec1fccbce14', 'v0.0.107'),
+    ('inceptionv4', '0488', 'a828ae6ccccb3178257d20e5f17cc8c6ac4348cc', 'v0.0.543'),
+    ('inceptionresnetv2', '0470', '4ea29355ae39ececb733e949dfdcbdff72272559', 'v0.0.547'),
     ('polynet', '0453', '742803144e5a2a6148212570726350da09adf3f6', 'v0.0.96'),
-    ('nasnet_4a1056', '0795', '5c78908e38c531283d86f9cbe7e14c2afd85a7ce', 'v0.0.97'),
+    ('nasnet_4a1056', '0790', 'f89dd74f47e42c35c9a1182f248df1d319524db7', 'v0.0.495'),
     ('nasnet_6a4032', '0424', '73cca5fee009db77412c5fca7c826b3563752757', 'v0.0.101'),
     ('pnasnet5large', '0428', '998a548f44ac1b1ac6c4959a721f2675ab5c48b9', 'v0.0.114'),
-    ('spnasnet', '0867', 'a223136fdad2a04e7ffe5721644227e8c9bbe985', 'v0.0.416'),
+    ('spnasnet', '0776', '09cc881e024d69ab3bd88bef332becb6147a0651', 'v0.0.490'),
     ('efficientnet_b0', '0722', '041a8346ad6a13dbb66384d9a41ed20d959d3e77', 'v0.0.364'),
     ('efficientnet_b1', '0626', '455dcb2a05a1295c8f6b728d4f6c72c507e1369a', 'v0.0.376'),
     ('efficientnet_b0b', '0670', '8892ba581b0d81dbc8fe56c49d81d3dd007b1db8', 'v0.0.403'),
@@ -305,13 +320,15 @@ _model_sha1 = {name: (error, checksum, repo_release_tag) for name, error, checks
     ('efficientnet_edge_small_b', '0629', '5b398abc73c4c4870d88c62452ff919bec2440c9', 'v0.0.434'),
     ('efficientnet_edge_medium_b', '0553', '0b3c86d49b3684d19e6589030aeceb918faa648c', 'v0.0.434'),
     ('efficientnet_edge_large_b', '0477', '055436da0fa440933b906c528cb34b200e28f73c', 'v0.0.434'),
-    ('mixnet_s', '0739', '54434771161c33256d67748ad3460556dc4a14d5', 'v0.0.412'),
-    ('mixnet_m', '0678', '810b89677e81fafe256c2396ed3984af7740c91d', 'v0.0.413'),
-    ('mixnet_l', '0603', '0576f35d60442379df422268e0f3070af82c3b72', 'v0.0.414'),
-    ('resneta18', '0862', 'e3c0b12d88d9ae9cc9bed642aa2fdb701628335d', 'v0.0.470'),
-    ('resneta50b', '0541', '535a978dc0d5f0b26def1bd00e7c63c8cad9a1f2', 'v0.0.452'),
-    ('resneta101b', '0487', 'fad05e5777b8a519dc24e2884ed17dffbc8c3dbb', 'v0.0.452'),
-    ('resneta152b', '0465', '05f96c54acfa844c249b34a40e360fc8e29d4064', 'v0.0.452'),
+    ('mixnet_s', '0703', '135aa0426712a9f60afe2cfff2df9607f3fc2d68', 'v0.0.493'),
+    ('mixnet_m', '0631', '0881aba9281e3cae3e7cddd75d385c3cccdf7e25', 'v0.0.493'),
+    ('mixnet_l', '0557', '94cbf10cb34c3e3940117d86c28bcc6dbfe9e005', 'v0.0.500'),
+    ('resneta10', '1159', 'a66e01d9f567ce747e7c255adac848a33c54a3a5', 'v0.0.484'),
+    ('resnetabc14b', '0956', '6f8c36067feb2d27b5e0813bf18ef29038db0d70', 'v0.0.477'),
+    ('resneta18', '0802', '225dd3ae0eac3ce3815732ac4ab0e25df709a75c', 'v0.0.486'),
+    ('resneta50b', '0534', '28eff48a72d892802dde424db3fd0e1a9c12be16', 'v0.0.492'),
+    ('resneta101b', '0442', 'cdf5f7ac2ad291cdc35b351e9220a490c8cc996c', 'v0.0.532'),
+    ('resneta152b', '0424', 'deaaaabf413821eb543621826c368493b9041438', 'v0.0.524'),
     ('resnetd50b', '0549', '17d6004b5c6c1b97cfb47377ae5076810c5d88be', 'v0.0.296'),
     ('resnetd101b', '0461', 'fead1bcb86bba2be4ed7f0033fa972dc613e3280', 'v0.0.296'),
     ('resnetd152b', '0467', 'd0fe2fe09c6462de17aca4a72bbcb08b76a66e02', 'v0.0.296'),
@@ -607,6 +624,7 @@ _model_sha1 = {name: (error, checksum, repo_release_tag) for name, error, checks
     ('fcn8sd_resnetd101b_ade20k', '3588', '081774b2fb373d7b759cda2160fa0d2599b1c5f1', 'v0.0.299'),
     ('fcn8sd_resnetd101b_coco', '6011', '05e97cc5f5fcdf1c5ec5c617062d43adfe150d88', 'v0.0.299'),
     ('icnet_resnetd50b_cityscapes', '6402', '6c8f86a53526ae107e58d5f645bc4de0da9c1bb1', 'v0.0.457'),
+    ('fastscnn_cityscapes', '6576', '9e0d75e56bde8d1643d3ff0053e55114c0a77ee9', 'v0.0.474'),
     ('sinet_cityscapes', '6031', '47d8ae7824bd297bbf25c2f33e3d4a86a503aefa', 'v0.0.437'),
     ('bisenet_resnet18_celebamaskhq', '0000', 'd72f0cf3101625bb4265e4cf5ae557b994f84d67', 'v0.0.462'),
     ('danet_resnetd50b_cityscapes', '6799', '9880a0eb9523ba2c1f98025f7d7115a2a4c1f376', 'v0.0.468'),
@@ -628,6 +646,19 @@ _model_sha1 = {name: (error, checksum, repo_release_tag) for name, error, checks
     ('lwopenpose2d_mobilenet_cmupan_coco', '3999', 'b4a22e7c2a05e53fe22185002c48e81f76c2d918', 'v0.0.458'),
     ('lwopenpose3d_mobilenet_cmupan_coco', '3999', '4658738ec27d46ee01f2cad4aa975914e9f7108c', 'v0.0.458'),
     ('ibppose_coco', '6486', '024d1fafb7471572129ccbb07d662f6d8ccdc758', 'v0.0.459'),
+    ('jasperdr10x5_en', '2189', 'bdbd9ddfd3b7ddcb9f6f76acf08ec0c70316cb9e', 'v0.0.546'),
+    ('jasperdr10x5_en_nr', '1789', '308e149aed9fe3fe31dadf54d1ecb4c8cddd955c', 'v0.0.546'),
+    ('quartznet5x5_en_ls', '4468', '80a3111a60da0a290d6bdbe628418273c3503dbc', 'v0.0.546'),
+    ('quartznet15x5_en', '1676', '16ac80d1a513653cf67ddc5f35a6419ed61daf06', 'v0.0.546'),
+    ('quartznet15x5_en_nr', '1773', '8a2304dee1d96bf2a21e0422b06d61f67dd267a7', 'v0.0.546'),
+    ('quartznet15x5_de', '1166', 'bafc8de8c7b451fd246061ab6a750f69d3c10af5', 'v0.0.546'),
+    ('quartznet15x5_fr', '1388', 'ff71b3c7b0c264bf8432301cdd5c16f7667767ce', 'v0.0.546'),
+    ('quartznet15x5_it', '1502', 'eb6a15ec72e600739500c3e6ca5bda6bdfe9ec7f', 'v0.0.546'),
+    ('quartznet15x5_es', '1295', '538f9e3422662d42752d1b0401b4e8ca6d41eba8', 'v0.0.546'),
+    ('quartznet15x5_ca', '0842', '2561a97010c31e5c4b89d92ac04a46a28b885a97', 'v0.0.546'),
+    ('quartznet15x5_pl', '1359', 'eeb19acae9d594db583dbd4278ba57e06caa58cc', 'v0.0.546'),
+    ('quartznet15x5_ru', '1647', '25a179643abc694ac5e8f95428a9d0eafd430aaa', 'v0.0.546'),
+    ('quartznet15x5_ru34', '0968', '518bc447695f28b651c22021434d2217cb24c96d', 'v0.0.549'),
 ]}
 
 imgclsmob_repo_url = 'https://github.com/osmr/imgclsmob'
@@ -646,14 +677,14 @@ def get_model_file(model_name,
     Return location for the pretrained on local file system. This function will download from online model zoo when
     model cannot be found or has mismatch. The root directory will be created if it doesn't exist.
 
-    Parameters
+    Parameters:
     ----------
     model_name : str
         Name of the model.
     local_model_store_dir_path : str, default $MXNET_HOME/models
         Location for keeping the model parameters.
 
-    Returns
+    Returns:
     -------
     file_path
         Path to the requested pretrained model file.
