@@ -4,7 +4,7 @@
     https://arxiv.org/abs/1707.07012.
 """
 
-__all__ = ['NASNet', 'nasnet_4a1056', 'nasnet_6a4032']
+__all__ = ['NASNet', 'nasnet_4a1056', 'nasnet_6a4032', 'nasnet_dual_path_sequential']
 
 import os
 from mxnet import cpu
@@ -39,7 +39,7 @@ class NasDualPathScheme(object):
     x_prev : Tensor
         Previous processed tensor.
 
-    Returns
+    Returns:
     -------
     x_next : Tensor
         Next processed tensor.
@@ -73,7 +73,7 @@ def nasnet_dual_path_scheme_ordinal(block,
     x : Tensor
         Current processed tensor.
 
-    Returns
+    Returns:
     -------
     x_next : Tensor
         Next processed tensor.
@@ -180,7 +180,7 @@ def process_with_padding(x,
     pad_width : tuple of int, default (0, 0, 0, 0, 1, 0, 1, 0)
         Whether the layer uses a bias vector.
 
-    Returns
+    Returns:
     -------
     NDArray
         Resulted tensor.
